@@ -162,7 +162,7 @@ class OrderBook:
 
     @property
     def spread(self) -> float:
-        return round_down(self.sells[0].price / self.buys[0].price - 1, 6)
+        return round_down(self.sells[-1].price / self.buys[0].price - 1, 6)
 
 
 @dataclass
